# ListBillingBalanceTransactions

Response object for customer balance transactions.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**has_more** | **bool** | Whether or not there are more elements available after this set. If false, this set comprises the end of the list.  | [optional] 
**data** | [**[BillingBalanceTransaction]**](BillingBalanceTransaction.md) | A list of Balance Transactions  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


